#!/bin/ksh
# Licensed Materials - Property of IBM
# 5724-S67
# (c) Copyright IBM Corp. 1998, 2007   All Rights Reserved.
# US Government Users Restricted Rights - Use, duplication or disclosure restricted by GSA ADP Schedule Contract with IBM Corp.

ACTUATOR_LOG=../log/${13}.log
echo `date "+%a %D %T"` Processing started. > $ACTUATOR_LOG

#checking input parameters
if [ -n "$1" ] ; then
 TEMPFILE1=$1
else
 echo `date "+%a %D %T"` Output file name is not defined. >> $ACTUATOR_LOG
 exit 1
fi

JAVA_BINARY=java

if [ -n "${13}" ] ; then 
 PROPSFILE=${13}
else
 echo `date "+%a %D %T"` PROPSFILE is not defined >> $ACTUATOR_LOG 
 exit 1
fi

# LDAP variables
LDAP_ENABLED=1
LDAP_HOST=127.0.0.1
LDAP_PORT=389
USER_OBJECTCLASS=inetOrgPerson
GROUP_OBJECTCLASS=groupOfNames
USER_BASEDN="c=*"
GROUP_BASEDN="c=*"
USERID_ATTRIBUTE=uid
AUTHID_ATTRIBUTE=uid
GROUPNAME_ATTRIBUTE=cn
SEARCH_DN=
SEARCH_PW=
GROUP_LOOKUP_METHOD=SEARCH_BY_DN
GROUP_LOOKUP_ATTRIBUTE=member

#cleaning output file
if [ -f $TEMPFILE1 ] ; then
 rm -f $TEMPFILE1 
fi

#checking if LDAP is enabled
if [ -n "$6" ] ; then
 if [ "$6" = "skip" ] ; then
  LDAP_ENABLED=0
 fi
 if [ "$6" = "Skip" ] ; then
  LDAP_ENABLED=0
 fi
 if [ "$6" = "SKIP" ] ; then
  LDAP_ENABLED=0
 fi
else
 LDAP_ENABLED=0
fi

if [ $LDAP_ENABLED -eq 1 ] ; then
 LDAP_SEQURITY_FILE=$6
fi

# begin to work with LDAP
if [ $LDAP_ENABLED -eq 1 ] ; then
     if [ -r "$LDAP_SEQURITY_FILE" ] ; then
         echo `date "+%a %D %T"` Start getting LDAP users and groups. >> $ACTUATOR_LOG
         for i in `cat "$LDAP_SEQURITY_FILE" | grep "^[a-zA-Z0-9]" | sed -e 's/ //g'`; do
             case `echo $i | cut -d = -f 1` in
             "LDAP_HOST")
                         LDAP_HOST=`echo $i | cut -d = -f 2` 
                         ;;
             "USER_OBJECTCLASS")
                         USER_OBJECTCLASS=`echo $i | cut -d = -f 2`
                         ;;
             "GROUP_OBJECTCLASS")
                         GROUP_OBJECTCLASS=`echo $i | cut -d = -f 2`
                         ;;
             "USER_BASEDN")
                         USER_BASEDN=`echo $i | sed -e 's/^USER_BASEDN=//'`
                         ;;
             "GROUP_BASEDN")
                         GROUP_BASEDN=`echo $i | sed -e 's/^GROUP_BASEDN=//'`
                         ;;
             "USERID_ATTRIBUTE")
                         USERID_ATTRIBUTE=`echo $i | cut -d = -f 2`
                         ;;
             "AUTHID_ATTRIBUTE")
                         AUTHID_ATTRIBUTE=`echo $i | cut -d = -f 2`
                         ;;
             "GROUPNAME_ATTRIBUTE")
                         GROUPNAME_ATTRIBUTE=`echo $i | cut -d = -f 2`
                         ;;
             "GROUP_LOOKUP_ATTRIBUTE")
                         GROUP_LOOKUP_ATTRIBUTE=`echo $i | cut -d = -f 2`
                         ;;
             "GROUP_LOOKUP_METHOD")
                        GROUP_LOOKUP_METHOD=`echo $i | cut -d = -f 2`
                         ;;
             "SEARCH_DN")
                         SEARCH_DN=`echo $i | sed -e 's/^SEARCH_DN= *//'`
                         ;;
             "SEARCH_PW")
                         SEARCH_PW=`echo $i | cut -d = -f 2`
                         ;;
             *)
                         echo other parameter is defined 
                         ;;
             esac
         done 
         A=$LDAP_HOST
         LDAP_HOST=`echo $A | sed -e 's/:.*$//'`
         LDAP_PORT=`echo $A | sed -e 's/^.*://'`
         if [ "$LDAP_PORT" = "$LDAP_HOST" ] ; then
             LDAP_PORT=389
         fi
        else 
         echo `date "+%a %D %T"` LDAP configfile does not exist.>> $ACTUATOR_LOG
         echo `date "+%a %D %T"` Processing finished \(FAILURE\). >> $ACTUATOR_LOG
         return 1
        fi
fi

if [ $LDAP_ENABLED -eq 0 ] ; then  
 if [ ! -n "`uname | grep Linux`" ] ; then
   echo `date "+%a %D %T"` Collecting OS users and groups information.>> $ACTUATOR_LOG
   ../bin/getgroups.sh $TEMPFILE1
    if [ ! $? -eq 0 ] ; then
      echo `date "+%a %D %T"` Failed to collect OS users and groups information.>> $ACTUATOR_LOG
      echo `date "+%a %D %T"` Processing finished \(FAILURE\). >> $ACTUATOR_LOG
      return 1
    else
      echo `date "+%a %D %T"` OS users and groups are collected successfully. >> $ACTUATOR_LOG
      echo `date "+%a %D %T"` Processing finished \(SUCCESS\). >> $ACTUATOR_LOG
      return 0
    fi
 fi
else 
    if [ -r "$LDAP_SEQURITY_FILE" ] ; then
         if [ ! `which $JAVA_BINARY` ] ; then
          echo `date "+%a %D %T"` Unable to find java executable. Please \, check the manual. >> $ACTUATOR_LOG
          echo `date "+%a %D %T"` Processing finished \(FAILURE\). >> $ACTUATOR_LOG
          return 1
         fi
         $JAVA_BINARY -classpath "../bin/getViper2ldapgroups.jar" nl.consul.cea.gensub.db2viper.java.CollectViperGroups -LDAPHost?"$LDAP_HOST" -LDAPPort?"$LDAP_PORT" -UserName?"$SEARCH_DN" -Password?"$SEARCH_PW" -USER_BASEDN?"$USER_BASEDN" -AUTHID_ATTRIBUTE?"$AUTHID_ATTRIBUTE" -USER_OBJECTCLASS?"$USER_OBJECTCLASS" -GROUP_OBJECTCLASS?"$GROUP_OBJECTCLASS" -GROUP_BASEDN?"$GROUP_BASEDN" -GROUPNAME_ATTRIBUTE?"$GROUPNAME_ATTRIBUTE" -GROUP_LOOKUP_METHOD?"$GROUP_LOOKUP_METHOD" -GROUP_LOOKUP_ATTRIBUTE?"$GROUP_LOOKUP_ATTRIBUTE" -Filename?"$TEMPFILE1" 2>> $ACTUATOR_LOG
         if [ ! $? -eq 0 ] ; then
          echo `date "+%a %D %T"` java run error. Failed to collect LDAP information.>> $ACTUATOR_LOG
         else
          echo `date "+%a %D %T"` LDAP information collect is finished. >> $ACTUATOR_LOG
         fi
    fi 
 echo `date "+%a %D %T"` Finished getting LDAP users and groups. >> $ACTUATOR_LOG
 echo `date "+%a %D %T"` Processing finished \(SUCCESS\). >> $ACTUATOR_LOG
fi

return 0
