REM Licensed Materials - Property of IBM
REM 5724-S67
REM (c) Copyright IBM Corp. 1998, 2007   All Rights Reserved.
REM US Government Users Restricted Rights - Use, duplication or disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
@echo off
goto comment

    *************************************************************************
    * Actuator batch script for DB2 Universal Database Event Source.        *
    *                                                                       *
    * Made 30Dec2005 accordingly CeA_v6.0_TDD_EE0408009_IBM_DB2_UDB         *
    *                                                                       *
    * Consul Pipe-A                                                         *
    *************************************************************************

:comment
setlocal
rem ----- Receive parameters from the InSight actuator
set temp_file1=%1
set temp_file2=%2
set temp_file3=%3
set temp_file4=%4
set temp_file5=%5
set db2_folder=%~6
set instance_name=%~7
set UserName=%8
set Password=%9
shift
set Truncate=%9
shift
set props_file=%9

if %temp_file1%=="" (
    echo ERROR: not all input parameters, enter name of 1 temporary file
    echo Exit with return code - 1
    exit /b 1
)
if %temp_file2%=="" (
    echo ERROR: not all input parameters, enter name of 2 temporary file
    echo Exit with return code - 1
    exit /b 1
)
if %temp_file3%=="" (
    echo ERROR: not all input parameters, enter name of 3 temporary file
    echo Exit with return code - 1
    exit /b 1
)
if %temp_file4%=="" (
    echo ERROR: not all input parameters, enter name of 4 temporary file
    echo Exit with return code - 1
    exit /b 1
)
if %temp_file5%=="" (
    echo ERROR: not all input parameters, enter name of 5 temporary file
    echo Exit with return code - 1
    exit /b 1
)
if "%db2_folder%"=="" (
    echo ERROR: not all input parameters, enter db2 folder name
    echo Exit with return code - 1
    exit /b 1
)
if "%instance_name%"=="" (
    echo ERROR: not all input parameters, enter db2 instance name
    echo Exit with return code - 1
    exit /b 1
)
if %props_file%=="" (
    echo ERROR: not all input parameters, enter name of property file
    echo Exit with return code - 1
    exit /b 1
)

rem ----- Create actuator progress log file
if not exist ..\log mkdir ..\log
type nul > ..\log\%props_file%.log
echo Date: %date% Time: %time% Start processing >> ..\log\%props_file%.log

rem ----- Set DB2INSTANCE environment variable to %instance_name% value
set db2instance=%instance_name%

rem ----- Set %db2_log_path% variable to "%db2_folder%\%instance_name%\security" value
set db2_log_path="%db2_folder%\%instance_name%\security"

rem ----- QE0807002: Take 'LastPruneTime' from propsfile
if EXIST "%props_file%" (
  for /F "delims=" %%I in ('findstr /R "^[0-9][0-9]*$" "%props_file%"') DO (set LastPruneTime=%%I)
  )
echo LastPruneTime: %LastPruneTime% >> ..\log\%props_file%.log

for /F "delims=" %%I IN ('..\bin\date.exe +%%Y%%m%%d%%H') DO (set CurrentTime=%%I)
rem ---- END QE0807002

rem ----- If the following files %db2_log_path%\*.del exist then remove them.
rem ----- If failed then finish work with return code 3
if exist %db2_log_path%\*.del (
    del /q /f %db2_log_path%\*.del
    if exist %db2_log_path%\*.del (
        echo ERROR: remove of %db2_log_path%\*.del files end with error >> ..\log\%props_file%.log
        echo Exit with return code - 3 >> ..\log\%props_file%.log
        exit /b 3
    ) else (
        echo Old "*.del" files in %instance_name% instance were removed successfully >> ..\log\%props_file%.log
    )
)

rem ----- Run "%db2_folder%\bin\db2audit.exe flush" command

if %UserName%=="" (
"%db2_folder%\bin\db2audit.exe" flush
) else (
..\bin\psexec \\127.0.0.1 -u %UserName% -p %Password% "%db2_folder%\bin\db2audit.exe" flush >> ..\log\%props_file%.log
)

if errorlevel 1 (
    echo ERROR: "%db2_folder%\bin\db2audit.exe flush" command doesn't properly executed >> ..\log\%props_file%.log
    echo "Check DB2 8.1 - 9.1 event source credential." >> ..\log\%props_file%.log
    echo Exit with return code - 1 >> ..\log\%props_file%.log
    exit /b 1
) else (
    echo "db2audit flush" operation succeeded >> ..\log\%props_file%.log
)

rem ----- Run "%db2_folder%\bin\db2audit.exe extract delasc category audit, checking, secmaint, sysadmin, validate" command
if %UserName% == "" (
"%db2_folder%\bin\db2audit.exe" extract delasc category audit, checking, secmaint, sysadmin, validate
) else (
..\bin\psexec \\127.0.0.1 -u %UserName% -p %Password% "%db2_folder%\bin\db2audit.exe" extract delasc category audit, checking, secmaint, sysadmin, validate >> ..\log\%props_file%.log
)

if errorlevel 1 (
    echo ERROR: "%db2_folder%\bin\db2audit.exe extract delasc" command doesn't properly executed >> ..\log\%props_file%.log
    echo "Check DB2 8.1 - 9.1 event source credentials." >> ..\log\%props_file%.log
    echo Exit with return code - 1 >> ..\log\%props_file%.log
    exit /b 1
) else (
    echo "db2audit extract delasc" operation succeeded >> ..\log\%props_file%.log
)


rem ----- QE0807002: If option "truncate" is set to 'yes' - get rid of the events we've already collected by prunning all records up to YYYYMMDDHH time in db2audit.log to resolve problem with high cpu 
rem ----- and memory usage.

if "%Truncate%" EQU "yes" (
   echo Truncate requested... Prunning... >> ..\log\%props_file%.log
   echo "Current time: %CurrentTime% LastPruneTime: %LastPruneTime%" >> ..\log\%props_file%.log
   if "%CurrentTime%" GTR "%LastPruneTime%" (
     set LastPruneTime=%CurrentTime%
     echo "Prunning records up to %CurrentTime% ..." >> ..\log\%props_file%.log
     if %UserName%=="" (
       "%db2_folder%\bin\db2audit.exe" prune date %CurrentTime%
     ) else (
         ..\bin\psexec \\127.0.0.1 -u %UserName% -p %Password% "%db2_folder%\bin\db2audit.exe" prune date %CurrentTime% >> ..\log\%props_file%.log
     )
   ) else (
       echo "Will not prune because all records are up to date..." >> ..\log\%props_file%.log
   )
 )
rem ----END QE0807002


rem ----- Set %none_log_access% variable to 1
set none_log_access=1

rem ----- Call getdb2recs.vbs script
rem ----- If the getdb2recs.vbs script return code 0, set %none_log_access% variable to 0
set executable=cscript.exe //B //NoLogo ..\bin\getdb2recs.vbs
call %executable% %db2_log_path% "audit.del" %temp_file1% %props_file%
if %errorlevel%==0 set none_log_access=0

set executable=cscript.exe //B //NoLogo ..\bin\getdb2recs.vbs
call %executable% %db2_log_path% "checking.del" %temp_file2% %props_file%
if %errorlevel%==0 set none_log_access=0

set executable=cscript.exe //B //NoLogo ..\bin\getdb2recs.vbs
call %executable% %db2_log_path% "secmaint.del" %temp_file3% %props_file%
if %errorlevel%==0 set none_log_access=0

set executable=cscript.exe //B //NoLogo ..\bin\getdb2recs.vbs
call %executable% %db2_log_path% "sysadmin.del" %temp_file4% %props_file%
if %errorlevel%==0 set none_log_access=0

set executable=cscript.exe //B //NoLogo ..\bin\getdb2recs.vbs
call %executable% %db2_log_path% "validate.del" %temp_file5% %props_file%
if %errorlevel%==0 set none_log_access=0

rem ----- If %none_log_access% variable is equal to 1, then finish work with return code 2
if %none_log_access%==1 (
    echo ERROR: none of logfiles is accessible or file ..\bin\getdb2recs.vbs doesn't exist >> ..\log\%props_file%.log
    echo Exit with return code - 2 >> ..\log\%props_file%.log
    exit /b 2
)

rem ----- Create\rewrite %props_file% file
rem ----- Obtain %USERDOMAIN% system environment variable
type nul > %props_file%
echo _domainname=%USERDOMAIN% >> %props_file%
rem DB2 9.1 update
rem checking if LDAP is enabled
if not exist %props_file%.dir (mkdir %props_file%.dir)
set DBM_CFG="%props_file%.dir\db2_cfg.txt"
set /A LDAP_ENABLED=0
if exist %DBM_CFG% ( del %DBM_CFG% )
"%db2_folder%\bin\db2cmd.exe" -c -w "db2 -r %DBM_CFG% get dbm cfg"
if %ERRORLEVEL% NEQ 0 (
 echo %date% %time% Unable to call db2 and get DBM configuration.>> ..\log\%props_file%.log
 )
 
for /F "delims== tokens=1,2" %%i in ('type %DBM_CFG%') do (
     if "%%i"==" Client Userid-Password Plugin          (CLNT_PW_PLUGIN) " (
         if "%%j"==" IBMLDAPauthclient" (set /A LDAP_ENABLED=1)
        )
     if "%%i"==" Server Userid-Password Plugin        (SRVCON_PW_PLUGIN) " (
         if "%%j"==" IBMLDAPauthserver" (set /A LDAP_ENABLED=1)
        )
    )

if %LDAP_ENABLED% EQU 1 ( echo _ldapenable=YES >> %props_file% ) else (echo _ldapenable=NO >> %props_file% )
    
rem end update for DB2 9.1
echo encoding1=UTF-8 >> %props_file%
echo encoding2=UTF-8 >> %props_file%
echo encoding3=UTF-8 >> %props_file%
echo encoding4=UTF-8 >> %props_file%
echo encoding5=UTF-8 >> %props_file%

rem ----- QE0807002: Put 'CurrentTime' into propsfile
echo %LastPruneTime%>>%props_file%
rem ----- END QE0807002

rem ----- Add contents of files, which were created by getdb2recs.vbs to %props_file% file
if exist %props_file%.audit.del    type %props_file%.audit.del>>%props_file%
if exist %props_file%.checking.del type %props_file%.checking.del >> %props_file%
if exist %props_file%.secmaint.del type %props_file%.secmaint.del >> %props_file%
if exist %props_file%.sysadmin.del type %props_file%.sysadmin.del >> %props_file%
if exist %props_file%.validate.del type %props_file%.validate.del >> %props_file%

rem ----- Remove files
if exist %props_file%.audit.del    del /q /f %props_file%.audit.del
if exist %props_file%.checking.del del /q /f %props_file%.checking.del
if exist %props_file%.secmaint.del del /q /f %props_file%.secmaint.del
if exist %props_file%.sysadmin.del del /q /f %props_file%.sysadmin.del
if exist %props_file%.validate.del del /q /f %props_file%.validate.del

rem ----- Finish work with return code 0
echo Date: %date% Time: %time% Finish processing >> ..\log\%props_file%.log
rem DB2 9.1 update
rmdir %PROPS_FILE%.dir /S /q
rem end update for DB2 9.1
exit /b 0

