#!/bin/ksh
# Licensed Materials - Property of IBM
# 5724-S67
# (c) Copyright IBM Corp. 1998, 2008   All Rights Reserved.
# US Government Users Restricted Rights - Use, duplication or disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
TEMPFILE1=$1
GROUP_FILE=$2
DB_PORT=$3
DB_NAME=$4
USER=$5
PASS=$6
PROPSFILE=$7

export PROPSFILE

# actuator progress log file name
LOG_FILE="../log/$PROPSFILE.log"

echo "[`date`] Processing started ..." > $LOG_FILE

# obtain hostname
HOST_NAME=`grep "SystemName" $PROPSFILE | tr "=" " " | awk '{print $2}' | col -b`

# set of  vars for sql-quary
SQL_FILE="groupsadmin.sql_$PROPSFILE"
TDCOLUMN=""
IDCOLUMN=""
TABLENAME="jac_sys.users"
FILE_NAME=$TEMPFILE1.src

# SQL-query for jac_sys.admin_log
echo "SELECT f1.USE_ID, f1.USERID, f1.NAME ,f3.NAME FROM JAC_SYS.USERS f1 LEFT OUTER JOIN JAC_SYS.UGP_USE_MEMBERS f2 ON f1.USE_ID=f2.USE_ID LEFT OUTER JOIN JAC_SYS.USE_GROUPS f3 ON f2.UGP_ID=f3.UGP_ID" > $SQL_FILE

echo "Starting collect from table $TABLENAME" >> $LOG_FILE

# running gettscmlogs_shared.sh
`../bin/gettscm_shared.sh "$FILE_NAME" "$HOST_NAME" "$DB_PORT" "$DB_NAME" "$USER" "$PASS" "$SQL_FILE" "$TDCOLUMN" "$IDCOLUMN"`

code=$?
if [ $code = 0 ];
then
   echo "Collect from table $TABLENAME is finished [SUCCESS]" >> $LOG_FILE
else
   echo "Warning: Collect from table $TABLENAME is finished [FAILURE]" >> $LOG_FILE
   exit 1
fi

# delete error.sql file
rm -f $SQL_FILE

# ITYPE==1 first sting is parsing ..==2 next
ITYPE=0
# constants to store temp results of persons and groups, and output file
CFILE_PERSONS="temp_persons.tmp_$PROPSFILE"
CFILE_GROUPS="temp_groups.tmp_$PROPSFILE"
CFILE_OUTPUT=$TEMPFILE1
# string constant = ["0"]
CNULL='"0"'
# create files with headers
`echo "[Persons]" > $CFILE_PERSONS`
`echo "[SourceGroup]" > $CFILE_GROUPS`

IFS=";"
while read DROP1 DROP2 NAME REALNAME GROUPNAME DROP3; do
#   echo "$NAME -> $REALNAME -> $GROUPNAME"
   if [ $ITYPE -eq 1 ];
   then
      # if NAME is not empty
      if [ ! -z $REALNAME ];
      then
         echo "\"$REALNAME\" \"$REALNAME\" $CNULL" >>$CFILE_PERSONS
         echo "{" >>$CFILE_PERSONS
         echo "     match logonname \"$NAME\"" >>$CFILE_PERSONS
         echo "}" >>$CFILE_PERSONS
       fi
 # if GROUPNAME is not empty
       if [ ! -z $GROUPNAME ];
         then
            echo "\"$GROUPNAME\"" >>$CFILE_GROUPS
            echo "{" >>$CFILE_GROUPS
            echo "     match logonname \"$NAME\"" >>$CFILE_GROUPS
            echo "}" >>$CFILE_GROUPS
        fi
   else
      let ITYPE=1;
   fi
done < $FILE_NAME

# concatinate files
cat $CFILE_GROUPS >> $CFILE_PERSONS
# rename file_persons to file_output
cat $CFILE_PERSONS > $CFILE_OUTPUT
# delete temp files
rm $CFILE_GROUPS
rm $CFILE_PERSONS

echo "[`date`] Processing finished. [SUCCESS] " >> $LOG_FILE

exit 0
