#!/bin/ksh
TEMP_FILE=$1
HOST=""
PORT=$3
USER_NAME=$4
PASSWORD=$5
WAS_INSTALL_DIR=$6
PROPS_FILE=$7

act_log_file="../log/`basename $PROPS_FILE`.log";

echo "[`date`] Processing start. ">$act_log_file;

if [ "$PROPS_FILE" = "" ]; 
then
   echo "[`date`] Failure: Missing property file argument">>$act_log_file;
   echo "[`date`] Processing finished. [FAILURE]">>$act_log_file;
   exit 1;
fi

HOST=`grep "SystemName" $PROPS_FILE | awk '{print $3}'`

if [ "$HOST" = "" ]; 
then
   echo "[`date`] Failure: Missing parameter SystemName from PROPS_FILE">>$act_log_file;
   echo "[`date`] Processing finished (Return code 1)">>$act_log_file;
   exit 1;
fi

if [ "$TEMP_FILE" = "" ]; 
then
   echo "[`date`] Failure: Missing output file argument">>$act_log_file;
   echo "[`date`] Processing finished. [FAILURE]">>$act_log_file;
   exit 1;
fi

if [ "$PORT" = "" ]; 
then
   echo "[`date`] Failure: Missing WAS repository SOAP port argument">>$act_log_file;
   echo "[`date`] Processing finished. [FAILURE]">>$act_log_file;
   exit 1;
fi

if [ "$USER_NAME" = "" ]; 
then
   echo "[`date`] Warning: Missing Repository User argument">>$act_log_file;
fi

if [ "$PASSWORD" = "" ]; 
then
   echo "[`date`] Warning: Missing Repository Password argument">>$act_log_file;
fi

if [ "$WAS_INSTALL_DIR" = "" ]; 
then
   echo "[`date`] Failure: Missing WAS installation directory argument">>$act_log_file;
   echo "[`date`] Processing finished. [FAILURE]">>$act_log_file;
   exit 1;
fi                      

if [ -f "$WAS_INSTALL_DIR/properties/fsdb/_was_profile_default/default.sh" ]; then
    echo "[`date`] WebSphere component ($WAS_INSTALL_DIR/properties/fsdb/_was_profile_default/default.sh) found.">>$act_log_file;
    . $WAS_INSTALL_DIR/properties/fsdb/_was_profile_default/default.sh>>$act_log_file;
else
   echo "[`date`] WebSphere component  ('WAS installation directory'/properties/fsdb/_was_profile_default/default.sh) not found. Check 'WAS installation directory' ES property. [FAILURE]">>$act_log_file;
   exit 1;
fi

if [ -f "$WAS_USER_SCRIPT" ]; then
    echo "[`date`] WebSphere component <$WAS_USER_SCRIPT> found.">>$act_log_file;
    . $WAS_USER_SCRIPT>>$act_log_file; 
else
   echo "[`date`] WebSphere component <$WAS_USER_SCRIPT> not found. [FAILURE]">>$act_log_file;
   exit 1;
fi


if [ "$CLIENTSSL" = "" ]; 
then
# V6.0
"$JAVA_HOME/bin/java"  -Djava.security.auth.login.config="$WAS_HOME/properties/wsjaas_client.conf" -Djava.ext.dirs="$JAVA_HOME/jre/lib/ext:$WAS_EXT_DIRS:$WAS_HOME/plugins: $WAS_HOME/lib/WMQ/java/lib" -Dws.ext.dirs="$WAS_EXT_DIRS;%WAS_USER_DIRS:." -Djava.naming.factory.initial=com.ibm.websphere.naming.WsnInitialContextFactory  -Dserver.root="$WAS_HOME" "$CLIENTSAS" -Dcom.ibm.CORBA.loginSource=none -Duser.install.root="$USER_INSTALL_ROOT" -classpath "../bin/getwasgroups.jar:$WAS_CLASSPATH:." nl.consul.cea.gensub.iwasuis.java.GetWASGroups -host $HOST -port $PORT -username $USER_NAME -password $PASSWORD -chunk $TEMP_FILE -propsfile $PROPS_FILE -version 6.0 2>>$act_log_file 1>>$act_log_file
code=$?
if [ $code = 0 ];
then
   echo "[`date`] Processing finished. [SUCCESS]">>$act_log_file;
else
   echo "[`date`] Processing finished. [FAILURE]">>$act_log_file;
fi

else
# V6.1
"$JAVA_HOME/bin/java"  -Djava.security.auth.login.config="$WAS_HOME/properties/wsjaas_client.conf" -Dws.ext.dirs="$WAS_EXT_DIRS;$WAS_USER_DIRS:." -Djava.naming.factory.initial=com.ibm.websphere.naming.WsnInitialContextFactory  -Dserver.root="$WAS_HOME" "$CLIENTSAS" "$CLIENTSSL" -Duser.install.root="$USER_INSTALL_ROOT" -classpath "../bin/getwasgroups.jar:$WAS_CLASSPATH:$WAS_HOME/plugins/com.ibm.ws.security.crypto_6.1.0.jar:$WAS_HOME/bin/ProfileManagement/plugins/com.ibm.websphere.v61_6.1.0/ws_runtime.jar:$WAS_HOME/runtimes/com.ibm.ws.webservices.thinclient_6.1.0.jar:$WAS_HOME/plugins/com.ibm.ws.runtime_6.1.0.jar:." nl.consul.cea.gensub.iwasuis.java.GetWASGroups -host $HOST -port $PORT -username $USER_NAME -password $PASSWORD -chunk $TEMP_FILE -propsfile $PROPS_FILE -version 6.1 2>>$act_log_file 1>>$act_log_file
code=$?
if [ $code = 0 ];
then
   echo "[`date`] Processing finished. [SUCCESS]">>$act_log_file;
else
   echo "[`date`] Processing finished. [FAILURE]">>$act_log_file;
fi
fi