#!/bin/sh

CEA_GENACT_FUNCLIB=../bin/funclib.sh
export CEA_GENACT_FUNCLIB

# Source our function library. It contains generic functions. 
. $CEA_GENACT_FUNCLIB || exit 1

#######################################################
# Usage: err_exit <exit-code> [exit-message]
#######################################################
err_exit()
{
  debug $2
  if [ -f $TEMPFILE1 ]; then rm $TEMPFILE1; fi
  debug "Processing finished. [FAILURE]"
  exit $1
}
######################################################################
# export all envinroment variables which are needed for getoradblogs2.sh back-end actuator script     #
######################################################################
export_env_variables()
{
    export PROPSFILE
    export CEA_GENACT_FUNCLIB
    export CEA_GENACT_DEBUG_LOG

    export ORACLE_SID
    export ORA_INSTANCE
    export ORA_USER
    export ORA_PWD
    export ORACLE_HOME 

    export TEMPFILE

    export TABLE_NAME
    export TABLE_NAME9
    export TABLE_NAME10
    export TABLE_DESC
    export TABLE_DESC9
    export TABLE_DESC10
    export TABLE_HEAD
    export TABLE_HEAD9
    export TABLE_HEAD10
    export COL_TIME
    export COL_TIME9
    export COL_TIME10
    export LINE_SIZE
    export GETHEADER
    export PARAM_OUTPUT
    export NOTIMESTAMP
    export TIMESTAMPNAME
    export NOLINESCHECK
}

if [ -z "$1" ]; then err_exit 1 "Option #1 'Tempfile' must be specified!"; fi
if [ -z "$3" ]; then err_exit 1 "Option #3 'Oracle Instance' must be specified!"; fi
if [ -z "$4" ]; then err_exit 1 "Option #4 'Oracle User Name' must be specified!"; fi
if [ -z "$6" ]; then err_exit 1 "Option #6 'Oracle Home Path' must be specified!"; fi
eval PROPSFILE="\$$#"
if [ -z "$PROPSFILE" ]; then err_exit 1 "Last Option - Properties File must be specified!"; fi

# Parameters needed for getoradblogs2.sh
TEMPFILE1=$1
if [ -f $TEMPFILE1 ]; then rm $TEMPFILE1; fi
TEMPFILE="${TEMPFILE1}0"

# Parameters needed for oracle access
ORACLE_SID="$3"
ORA_INSTANCE="@$3"
ORA_USER="$4"
ORA_PWD="$5"
ORACLE_HOME="$6"
export ORACLE_HOME 


CEA_GENACT_DEBUG_LOG=../log/${PROPSFILE}.log
debug_init

if [ -f ${PROPSFILE}.ok ]; then rm ${PROPSFILE}.ok; fi

# Parameters needed for data acquisition
TABLE_NAME="applsys.wf_local_user_roles wlur"
TABLE_DESC="'\"'||wlur.role_name||'\"'||chr(10)||'{'||chr(10)||'   match logonname \"'||wlur.user_name||'\"'||chr(10)||'}' as str"
TABLE_HEAD="'[SourceGroup]'"
COL_TIME="str"
GETHEADER=""
NOTIMESTAMP="YES"
LINE_SIZE="800"
PARAM_OUTPUT="SET RECSEP OFF;"
NOLINESCHECK="YES"

debug "Information: Processing table WF_LOCAL_USER_ROLES"
#call back-end script to get data from Oracle DB
export_env_variables
../bin/getoradblogs2.sh

if [ ! -f "${PROPSFILE}.ok" ]
then 
  rm -f "$TEMPFILE" "$TEMPFILE1"
  if [ -f ${PROPSFILE} ]; then rm ${PROPSFILE}; fi
  debug "Data collect finished with errors."
  debug "Processing finished. [FAILURE]"
else
  if [ ! -f "$TEMPFILE" ]
  then 
    err_exit 1 "Result <${TEMPFILE1}> file does not exist."
  fi

  LINESCOUNT=`wc -l $TEMPFILE | sed -e 's/^ *\([0-9]\{1,\}\).*/\1/'`
  if [ $LINESCOUNT -le 3 ]
  then 
    rm -f "$TEMPFILE"
    err_exit 1 "No UIS data received."
  fi

  mv -f "$TEMPFILE" "$TEMPFILE1"

  if [ -f ${PROPSFILE}.ok ]; then rm ${PROPSFILE}.ok; fi
  if [ -f ${PROPSFILE} ]; then rm ${PROPSFILE}; fi

  debug "Processing finished. [SUCCESS]"
fi
