' Licensed Materials - Property of IBM
' 5724-S67
' (c) Copyright IBM Corp. 1998, 2007   All Rights Reserved.
' US Government Users Restricted Rights - Use, duplication or disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
' Licensed Materials - Property of IBM
' 5724-S67
' US Government Users Restricted Rights - Use, duplication or disclosure restricted by GSA ADP Schedule Contract with IBM Corp.

'*******************************************************
'
'
' Purpose: get audit data from Tandem machine
'          to local machine for processing by actuator
'
' Remarks: makes use of FTP protocol through crmftp.dll,
'          which should be registered.
'
' History: 20010703 Martijn EE105002: Created.
'          20010710 Martijn EE105002: Improved error
'                                     handling
'
'*******************************************************
Option Explicit
On Error Resume Next

'Copy arguments to named parameters
Dim OutputFile, Host, Username, Password
Dim CopySubVolume, AuditPrefix, PropsFName
OutputFile =    WScript.Arguments(0)
Host =          WScript.Arguments(1)
Username =      WScript.Arguments(2)
Password =      WScript.Arguments(3)
CopySubVolume = WScript.Arguments(4)
AuditPrefix =   WScript.Arguments(5)
PropsFName =    WScript.Arguments(6)

'Create general purpose objects
Dim fso, wshShell
Set fso = WScript.CreateObject("Scripting.FileSystemObject")
Set wshShell = WScript.CreateObject("WScript.Shell") 

'QE0804029: Determine LPI
Dim LPI, iProps
iProps = InStr(PropsFName, ".props")
LPI = Left(PropsFName, iProps - 1)

'QE0804029: Add LPI to TempFile name
Dim TempFile
TempFile = "genact-tandem" & "_" & LPI & ".tmp"

'Create LogFile
Dim LogFile, LogFileName
LogFileName = "gettandem" & Host & "_" & LPI & ".log" 'QE0804029: Add LPI to LogFile name
ClearError
Set LogFile = fso.OpenTextFile("..\log\" & LogFileName, 2, True, 0)
If Err.Number <> 0 Then
  Err.Clear
  Set LogFile = fso.OpenTextFile(LogFileName, 2, True, 0)
End If   
LogFile.Write "CeA Tandem Actuator [gettandemlog.vbs], " & Now & vbCrLf
If Err.Number <> 0 Then WScript.Echo "Unable to create logfile"

'Get local directory from OutputFile
Dim LocalDirPrefix
LocalDirPrefix = fso.GetParentFolderName(OutputFile)
If Len(LocalDirPrefix)>0 And Right(LocalDirPrefix, 1) <> "\" Then _
   LocalDirPrefix = LocalDirPrefix & "\"

'Create empty result file
ClearError
fso.CreateTextFile(OutputFile, 2, False).Close
If Err.Number <> 0 Then
  LogErr
  LogFile.Write "Unable to create output file: " & OutputFile & vbCrLf
  LogFile.Close
  WScript.Quit 1
End If

'Connect to FTP Host
Dim FTPHost
ClearError
Set FTPHost = WScript.CreateObject("CRMFTP.FileTransfer")
If Err.Number <> 0 Then
  LogErr
  LogFile.Write "Unable to create CRMFTP.FileTransfer Object" & vbCrLf
  LogFile.Close
  WScript.Quit 1
End If
ClearError
FTPHost.Connect Host, Username, Password, 2 'actPreConfig = 2
If Err.Number <> 0 Then
  LogErr
  LogFile.Write "Unable to connect to ftp host: " & Host & vbCrLf
  LogFile.Close
  WScript.Quit 1
End If  

'Get FileList from FTP Host
Dim FNames, Flags
Dim FName, Index
Dim Files(), AllFiles(), FileIndex, AllFilesIndex, FNamesCount, iBlank
FTPHost.SetCurrentDirectory CopySubVolume
FTPHost.Dir "", FNames, Flags

'Remove additional information from filenames that may be returned by the
'tandem ftp host.
FNamesCount = UBound(FNames) + 1
For FileIndex = 0 To FNamesCount - 1
  iBlank = InStr(FNames(FileIndex), " ")
  If iBlank > 0 Then FNames(FileIndex) = Left(FNames(FileIndex), iBlank - 1)
Next
ClearError

'QE0804029: Added usage of propsfile to fix duplication
Dim PropsFile, FirstFName, FirstFNameLenght, FirstFNumber, PrefLength
PrefLength = Len(AuditPrefix)
Set PropsFile = fso.OpenTextFile(PropsFName, 1, True, 0)
FirstFName = PropsFile.ReadLine
PropsFile.Close
If InStr(FirstFName, AuditPrefix) = 1 Then
  FirstFNameLenght = Len(FirstFName)
  FirstFNumber = Right(FirstFName, FirstFNameLenght - PrefLength)
  Else FirstFNumber = 0
End If

Dim FNameLenght, FileNo, LastFNumber, LastFName
FileIndex = 0
AllFilesIndex = 0
For Each FName In FNames
  If InStr(FName, AuditPrefix) = 1 Then
    If Flags(Index) = 0 Then
      FNameLenght = Len(FName)
      FileNo = Right(FName, FNameLenght - PrefLength)
      If FileNo>FirstFNumber Then
        If FileNo>LastFNumber Then
          LastFName = FName
          LastFNumber = FileNo
        End If
        ReDim Preserve Files(FileIndex)
        Files(FileIndex) = FName
        FileIndex = FileIndex + 1
      End If
      ReDim Preserve AllFiles(AllFilesIndex)
      AllFiles(AllFilesIndex) = FName
      AllFilesIndex = AllFilesIndex + 1
    End If
    Index = Index + 1
  End If  
Next
ClearError

'Exit if no files
If FileIndex = 0 Then
  FTPHost.Disconnect
  LogFile.Write "No files on FTP Host to download" & vbCrLf
  LogFile.Close
  WScript.Quit 0
End If

'Transfer files
Dim FFile, AnyError, NewFile
Index = 0
AnyError = False
For Each FFile In Files
  Err.Clear
  LogFile.Write "Getting file " & FFile & vbCrLf
  NewFile = FFile & "_" & LPI & ".tmp" 'QE0804029: Add LPI to transfered file name
  FTPHost.GetFile FFile, LocalDirPrefix & NewFile, 2, False 'tfmBinary = 2
  If Err.Number <> 0 Then
    LogErr
    LogFile.Write "Error getting file " & FFile & vbCrLf
    AnyError = True
  End If
  If Not AnyError Then
    fso.DeleteFile LocalDirPrefix & TempFile 'Copy current result to temporary file
    Err.Clear
    fso.MoveFile OutputFile, LocalDirPrefix & TempFile
    If Err.Number <> 0 Then
      LogErr
      LogFile.Write "Unable to rename """ & OutputFile & """ to """ & LocalDirPrefix & TempFile & """" & vbCrLf
      AnyError = True
    End If
  End If
  If Not AnyError Then   'Create new result file, including new file
    If wshShell.Run("cmd /c copy /b """ & LocalDirPrefix & TempFile & """ + """ _
      & LocalDirPrefix & NewFile & """ """ & OutputFile & """", 7, True) <> 0 Then
      LogFile.Write "Error appending file """ & LocalDirPrefix & FFile & """ to """ & LocalDirPrefix & TempFile & """" & vbCrLf
      AnyError = True
    End If
  End If
  fso.DeleteFile LocalDirPrefix & NewFile
  If AnyError Then Exit For
Next

'Remove temporary file
fso.DeleteFile LocalDirPrefix & TempFile

'Remove transfered files, or result file in case of error
If AnyError Then
  LogFile.Write "Removing local file " & OutputFile
  fso.DeleteFile OutputFile
Else  
  For Each FFile In AllFiles
    Err.Clear
    LogFile.Write "Removing remote file: " & FFile & vbCrLf
    FTPHost.DeleteFile FFile
    If Err.Number <> 0 Then
      LogErr
      LogFile.Write "Unable to delete remote file: " & FFile & vbCrLf
    End If
  Next 
End If

'QE0804029: Save the last file name in props file
Set PropsFile = fso.OpenTextFile(PropsFName, 2, True, 0)
PropsFile.WriteLine(LastFName)
PropsFile.Close

'Disconnect from FTP host
FTPHost.DisConnect

'Final message in case of no error
If AnyError Then
  LogFile.Write "Script terminated with errors" & vbCrLf
  LogFile.Close
  WScript.Quit 1 
Else
  LogFile.Write UBound(Files) + 1 & " files transfered" & vbCrLf
  LogFile.Close
  WScript.Quit 0
End If

Sub LogErr
  LogFile.Write "Error: " & Err.Number & ", " & Err.Description & vbCrLf
End Sub
  
Sub ClearError
  If Err.Number <> 0 Then LogErr
  Err.Clear
End Sub    
  








